import java.awt.*;
import javax.swing.*;

public class MultiBallsWorld extends JPanel {

    // Data Fields
    public static final int PANEL_WIDTH = 600;
    public static final int PANEL_HEIGHT = 400;
    private static final int BALL_COLLECTION_SIZE = 5;
    //
    private Ball[] balls = new Ball[BALL_COLLECTION_SIZE];

    // Constructors : guarantee that objects are placed into 
    // a proper initial state the moment they are created 
    // with the 'new' operator.
    public MultiBallsWorld(Color ballColor) {
        for (int i = 0; i < balls.length; i++) {
            balls[i] = new Ball(new Point(10, 15), 5);
            balls[i].setColor(ballColor);
            balls[i].setMotion(3.0+i, 6.0-i);
        }
    }

    @Override
    public void paint(Graphics g) {
        super.paint(g);
        Graphics2D g2d = (Graphics2D) g;
        for (Ball b : balls) {
            b.paint(g2d);
        }
    }

    public void run() {
        for (Ball b : balls) {
            b.move();
            // check boundary
            Point pos = b.location();
            if ((pos.x < b.radius()) ||
                (pos.x > PANEL_WIDTH - b.radius()))
                b.reflectHorz();
            if ((pos.y < b.radius()) ||
                (pos.y > PANEL_HEIGHT - b.radius()))
                b.reflectVert();
        }
        repaint();
        try {
            // wait for the graphics system 
            // to finish repainting!
            Thread.sleep(10); 
        } catch (InterruptedException e) {
            System.exit(0);
        }
    }
}
